
use strict;
use warnings;

use 5.005030;

use ExtUtils::MakeMaker 6.30;

use File::ShareDir::Install;
install_share dist => "share";


my %WriteMakefileArgs = (
  "ABSTRACT" => "Lightweight yet powerful web application framework",
  "AUTHOR" => "Dancer Core Developers",
  "BUILD_REQUIRES" => {
    "Module::Build" => "0.3601"
  },
  "CONFIGURE_REQUIRES" => {
    "ExtUtils::MakeMaker" => "6.30",
    "File::ShareDir::Install" => "0.03",
    "Module::Build" => "0.3601"
  },
  "DISTNAME" => "Dancer2",
  "EXE_FILES" => [
    "script/dancer2"
  ],
  "LICENSE" => "perl",
  "NAME" => "Dancer2",
  "PREREQ_PM" => {
    "App::Cmd::Setup" => 0,
    "Carp" => 0,
    "Class::Load" => 0,
    "Config::Any" => 0,
    "Cwd" => 0,
    "Data::Dumper" => 0,
    "Digest::SHA" => 0,
    "Encode" => 0,
    "Exporter" => "5.57",
    "Fcntl" => 0,
    "File::Basename" => 0,
    "File::Copy" => 0,
    "File::Find" => 0,
    "File::Path" => 0,
    "File::ShareDir" => 0,
    "File::Spec" => 0,
    "File::Spec::Functions" => 0,
    "File::Temp" => "0.22",
    "HTTP::Body" => 0,
    "HTTP::Date" => 0,
    "HTTP::Headers" => 0,
    "HTTP::Server::Simple::PSGI" => 0,
    "Hash::Merge::Simple" => 0,
    "IO::File" => 0,
    "JSON" => 0,
    "LWP::UserAgent" => 0,
    "List::Util" => 0,
    "MIME::Base64" => "3.13",
    "MIME::Types" => 0,
    "Moo" => "1.003000",
    "Moo::Role" => 0,
    "MooX::Types::MooseLike" => "0.16",
    "MooX::Types::MooseLike::Base" => 0,
    "POSIX" => 0,
    "Plack::Request" => 0,
    "Pod::Simple::Search" => 0,
    "Pod::Simple::SimpleTree" => 0,
    "Return::MultiLevel" => 0,
    "Role::Tiny" => "1.003000",
    "Scalar::Util" => 0,
    "Template" => 0,
    "Template::Tiny" => 0,
    "Test::Builder" => 0,
    "Test::More" => "0.92",
    "URI" => 0,
    "URI::Escape" => 0,
    "YAML::Any" => 0,
    "overload" => 0,
    "parent" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "TEST_REQUIRES" => {
    "Capture::Tiny" => "0.12",
    "ExtUtils::MakeMaker" => 0,
    "File::Temp" => "0.22",
    "FindBin" => 0,
    "HTTP::Body" => 0,
    "HTTP::Request" => 0,
    "HTTP::Request::Common" => 0,
    "HTTP::Server::Simple::PSGI" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "LWP::Protocol::PSGI" => "0.06",
    "Plack::Test" => 0,
    "Test::Fatal" => 0,
    "Test::MockTime" => 0,
    "Test::More" => "0.92",
    "Test::Script" => 0,
    "Test::TCP" => "1.13",
    "YAML" => 0,
    "YAML::Any" => 0,
    "lib" => 0,
    "utf8" => 0,
    "vars" => 0
  },
  "VERSION" => "0.12",
  "test" => {
    "TESTS" => "t/*.t t/dsl/*.t t/roles/*.t t/route-pod-coverage/*.t t/template_tiny/*.t"
  }
);


my %FallbackPrereqs = (
  "App::Cmd::Setup" => 0,
  "Capture::Tiny" => "0.12",
  "Carp" => 0,
  "Class::Load" => 0,
  "Config::Any" => 0,
  "Cwd" => 0,
  "Data::Dumper" => 0,
  "Digest::SHA" => 0,
  "Encode" => 0,
  "Exporter" => "5.57",
  "ExtUtils::MakeMaker" => 0,
  "Fcntl" => 0,
  "File::Basename" => 0,
  "File::Copy" => 0,
  "File::Find" => 0,
  "File::Path" => 0,
  "File::ShareDir" => 0,
  "File::Spec" => 0,
  "File::Spec::Functions" => 0,
  "File::Temp" => "0.22",
  "FindBin" => 0,
  "HTTP::Body" => 0,
  "HTTP::Date" => 0,
  "HTTP::Headers" => 0,
  "HTTP::Request" => 0,
  "HTTP::Request::Common" => 0,
  "HTTP::Server::Simple::PSGI" => 0,
  "Hash::Merge::Simple" => 0,
  "IO::File" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "JSON" => 0,
  "LWP::Protocol::PSGI" => "0.06",
  "LWP::UserAgent" => 0,
  "List::Util" => 0,
  "MIME::Base64" => "3.13",
  "MIME::Types" => 0,
  "Module::Build" => "0.3601",
  "Moo" => "1.003000",
  "Moo::Role" => 0,
  "MooX::Types::MooseLike" => "0.16",
  "MooX::Types::MooseLike::Base" => 0,
  "POSIX" => 0,
  "Plack::Request" => 0,
  "Plack::Test" => 0,
  "Pod::Simple::Search" => 0,
  "Pod::Simple::SimpleTree" => 0,
  "Return::MultiLevel" => 0,
  "Role::Tiny" => "1.003000",
  "Scalar::Util" => 0,
  "Template" => 0,
  "Template::Tiny" => 0,
  "Test::Builder" => 0,
  "Test::Fatal" => 0,
  "Test::MockTime" => 0,
  "Test::More" => "0.92",
  "Test::Script" => 0,
  "Test::TCP" => "1.13",
  "URI" => 0,
  "URI::Escape" => 0,
  "YAML" => 0,
  "YAML::Any" => 0,
  "lib" => 0,
  "overload" => 0,
  "parent" => 0,
  "strict" => 0,
  "utf8" => 0,
  "vars" => 0,
  "warnings" => 0
);


unless ( eval { ExtUtils::MakeMaker->VERSION(6.63_03) } ) {
  delete $WriteMakefileArgs{TEST_REQUIRES};
  delete $WriteMakefileArgs{BUILD_REQUIRES};
  $WriteMakefileArgs{PREREQ_PM} = \%FallbackPrereqs;
}

delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
  unless eval { ExtUtils::MakeMaker->VERSION(6.52) };

WriteMakefile(%WriteMakefileArgs);

{
package
MY;
use File::ShareDir::Install qw(postamble);
}


